@@ -117,6 +117,11 @@ $catalogue = new MessageCatalogue('en', array (
     'This URL is missing a top-level domain.' => 'This URL is missing a top-level domain.',
     'This value is too short. It should contain at least one word.|This value is too short. It should contain at least {{ min }} words.' => 'This value is too short. It should contain at least one word.|This value is too short. It should contain at least {{ min }} words.',
     'This value is too long. It should contain one word.|This value is too long. It should contain {{ max }} words or less.' => 'This value is too long. It should contain one word.|This value is too long. It should contain {{ max }} words or less.',
+    'This value does not represent a valid week in the ISO 8601 format.' => 'This value does not represent a valid week in the ISO 8601 format.',
+    'This value is not a valid week.' => 'This value is not a valid week.',
+    'This value should not be before week "{{ min }}".' => 'This value should not be before week "{{ min }}".',
+    'This value should not be after week "{{ max }}".' => 'This value should not be after week "{{ max }}".',
+    'This value is not a valid Twig template.' => 'This value is not a valid Twig template.',
   ),
   'security' => 
   array (
@@ -143,13 +148,13 @@ $catalogue = new MessageCatalogue('en', array (
   'messages' => 
   array (
     'shopware.installer.header_title' => 'Setup',
-    'shopware.installer.menuitem_language-selection' => 'Start',
+    'shopware.installer.menuitem_welcome' => 'Start',
     'shopware.installer.menuitem_requirements' => 'System requirements',
     'shopware.installer.menuitem_database-configuration' => 'Database configuration',
     'shopware.installer.menuitem_database-import' => 'Installation',
     'shopware.installer.menuitem_edition' => 'Shopware licence',
     'shopware.installer.menuitem_configuration' => 'Configuration',
-    'shopware.installer.menuitem_finish' => 'Done',
+    'shopware.installer.menuitem_finish' => 'Finish',
     'shopware.installer.menuitem_license' => 'GTC',
     'shopware.installer.license_incorrect' => 'The licence key you have entered does not appear to be valid.',
     'shopware.installer.license_does_not_match' => 'The licence key you have entered does not match any commercial Shopware version.',
@@ -159,19 +164,19 @@ $catalogue = new MessageCatalogue('en', array (
     'shopware.installer.forward' => 'Next',
     'shopware.installer.start' => 'Start',
     'shopware.installer.start_installation' => 'Start installation',
-    'shopware.installer.select_language_de' => 'German',
-    'shopware.installer.select_language_en' => 'English (United Kingdom)',
-    'shopware.installer.select_language_us' => 'English (United States of America)',
-    'shopware.installer.select_language_nl' => 'Dutch',
-    'shopware.installer.select_language_it' => 'Italian',
-    'shopware.installer.select_language_fr' => 'French',
-    'shopware.installer.select_language_es' => 'Spanish',
-    'shopware.installer.select_language_pt' => 'Portuguese',
-    'shopware.installer.select_language_pl' => 'Polish',
     'shopware.installer.select_language_cs' => 'Czech',
-    'shopware.installer.select_language_sv' => 'Swedish',
-    'shopware.installer.select_language_da' => 'Danish',
-    'shopware.installer.select_language_nb' => 'Norwegian',
+    'shopware.installer.select_language_da-DK' => 'Danish',
+    'shopware.installer.select_language_de' => 'German',
+    'shopware.installer.select_language_en-US' => 'English (United States of America)',
+    'shopware.installer.select_language_en' => 'English (United Kingdom)',
+    'shopware.installer.select_language_es-ES' => 'Spanish',
+    'shopware.installer.select_language_fr' => 'French',
+    'shopware.installer.select_language_it' => 'Italian',
+    'shopware.installer.select_language_nl' => 'Dutch',
+    'shopware.installer.select_language_no' => 'Norwegian',
+    'shopware.installer.select_language_pl' => 'Polish',
+    'shopware.installer.select_language_pt-PT' => 'Portuguese',
+    'shopware.installer.select_language_sv-SE' => 'Swedish',
     'shopware.installer.select_country_jam' => 'Jamaica',
     'shopware.installer.select_country_mmr' => 'Myanmar',
     'shopware.installer.select_country_pan' => 'Panama',
@@ -423,11 +428,10 @@ $catalogue = new MessageCatalogue('en', array (
     'shopware.installer.select_country_yem' => 'Yemen',
     'shopware.installer.select_country_zmb' => 'Zambia',
     'shopware.installer.select_country_zwe' => 'Zimbabwe',
-    'shopware.installer.language-selection_welcome_title' => 'Welcome to Shopware 6',
+    'shopware.installer.welcome_title' => 'Welcome to Shopware 6',
     'shopware.installer.language-selection_select_language' => 'Installation wizard language',
-    'shopware.installer.language-selection_header' => 'Your Shopware installation',
-    'shopware.installer.language-selection_info_message' => 'The language selected here only applies to this installation wizard. If you like, you can specify another language for your shop later.',
-    'shopware.installer.language-selection_welcome_message' => 'We are delighted you want to join our fantastic, global Shopware community. We will now take you through the installation process step by step. If you have any queries, simply take a look in our <a class="is--nowrap" href="https://forum.shopware.com" target="_blank">forum</a>, give us a call on <a class="is--nowrap" href="tel:0080074676260">00 800 746 7626 0 (free of charge)</a> or send us an <a class="is--nowrap" href="mailto:info@shopware.com">email</a>.',
+    'shopware.installer.welcome_header' => 'Your Shopware installation',
+    'shopware.installer.welcome_message' => 'We are delighted you want to join our fantastic, global Shopware community. We will now take you through the installation process step by step. If you have any queries, simply take a look in our <a class="is--nowrap" href="https://forum.shopware.com" target="_blank">forum</a>, give us a call on <a class="is--nowrap" href="tel:0080074676260">00 800 746 7626 0 (free of charge)</a> or send us an <a class="is--nowrap" href="mailto:info@shopware.com">email</a>.',
     'shopware.installer.requirements_header' => 'System requirements',
     'shopware.installer.requirements_header_files' => 'Files and directories',
     'shopware.installer.requirements_header_system' => 'System',
